==> icedtea-web_1.4.orig.tar.gz: icedtea-web-1.4/tests/reproducers/simple/simpletest2/testcases/SimpleTest2Test.java <==
/* SimpleTest2Test.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ServerAccess;
import org.junit.Assert;

import org.junit.Test;

public class SimpleTest2Test {

    private static ServerAccess server = new ServerAccess();


    @Test
    public void testSimpletest2lunchException() throws Exception {
        ServerAccess.ProcessResult pr=server.executeJavawsHeadless(null,"/simpletest2.jnlp");
        Assert.assertTrue("stdout should be < 1 , but was "+pr.stdout.trim().length(),pr.stdout.trim().length() < 1);
        String s="Correct exception";
        Assert.assertTrue("stderr should contains "+s+" but didn't",pr.stderr.contains(s));
        String ss="Exception";
        Assert.assertTrue("stderr should contains "+ss+" but did not",pr.stderr.contains(ss));
        Assert.assertFalse("testSimpletest2lunchException should not be terminated, but was",pr.wasTerminated);
        //Assert.assertFalse(0==pr.returnValue);exception and still returned 0?
    }



    }

==> icedtea-web_1.8.orig.tar.gz: icedtea-web-1.8/tests/reproducers/simple/simpletest2/testcases/SimpleTest2Test.java <==
/* SimpleTest2Test.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ProcessResult;
import net.sourceforge.jnlp.ServerAccess;

import org.junit.Assert;
import org.junit.Test;

public class SimpleTest2Test {

    private static ServerAccess server = new ServerAccess();


    @Test
    public void testSimpletest2lunchException() throws Exception {
        ProcessResult pr=server.executeJavawsHeadless(null,"/simpletest2.jnlp");
        String s="Correct exception";
        Assert.assertTrue("stderr should contains "+s+" but didn't",pr.stderr.contains(s));
        String ss="Exception";
        Assert.assertTrue("stderr should contains "+ss+" but did not",pr.stderr.contains(ss));
        Assert.assertFalse("testSimpletest2lunchException should not be terminated, but was",pr.wasTerminated);
    }



    }
